@@ -231,13 +231,14 @@ def update_data(data_bundle_path, base, minbar, tick, with_derivatives, concurre
     help="bundle 目录，默认为 ~/.rqalpha-plus"
 )
 @click.option("--sample", is_flag=True, help="下载数据样例")
-def download_data(data_bundle_path, sample=True):
+@click.option('-f', '--file-path', default=None, help="指定的压缩文件包")
+def download_data(data_bundle_path, sample=True, file_path=None):
     """
     下载样例回测数据。
     下载样例数据不使用rqdatac流量。
     """
     try:
         from rqalpha_plus.bundle import download_simple_bundle
-        return download_simple_bundle(data_bundle_path, sample=sample)
+        return download_simple_bundle(data_bundle_path, sample=sample, file_path=file_path)
     except ImportError:
         click.echo("""请先使用'rqsdk install rqalpha_plus'安装rqalpha_plus""")
