@@ -18,7 +18,7 @@ import os
 
 RQDATAC_DEFAULT_ADDRESS = "rqdatad-pro.ricequant.com:16011"
 PERMISSIONS_INFO_URL = "http://www.ricequant.com/api/rqlicense/get_permissions_readable_info"
-EXTRA_INDEX_URL = "--extra-index-url https://rquser:Ricequant8@pypi2.ricequant.com/simple/"
+EXTRA_INDEX_URL = "https://rquser:Ricequant8@pypi2.ricequant.com/simple/"
 BASH_FILE = [".bash_profile", ".bashrc", ".bash_profile", ".zshrc"]
 TAG_MAP = ["stock", "futures", "fund", "index", "option", "convertible", ]
 
