@@ -23,30 +23,18 @@ from rqsdk.const import BASH_FILE, EXTRA_INDEX_URL
 
 
 def pip_install(full_name, index_url):
-    command = "install -U -i {} {} {}".format(index_url, EXTRA_INDEX_URL, full_name)
+    command = "install -U -i {} --extra-index-url {} {}".format(index_url, EXTRA_INDEX_URL, full_name)
     if os.environ.get("RQSDK_PYPI"):
         command = "install -U -i {} {}".format(os.environ["RQSDK_PYPI"], full_name)
         click.echo("pip {}".format(command))
-    if sys.platform.startswith("win"):
-        script_update = os.path.join(os.path.dirname(os.path.abspath(__file__)), "script_update.py")
-        python_path = "\"{}\"".format(sys.executable)
-        script_update = "\"{}\"".format(script_update)
-        subprocess.Popen("{} {} {}".format(python_path, script_update, command), shell=True)
+
+    python_path = "\"{}\"".format(sys.executable)
+    if sys.platform == "win32":
+        end_help_msg = "& echo 请输入Enter继续..."
+        subprocess.Popen("{} -m pip {} ".format(python_path, command) + end_help_msg, shell=True)
         sys.exit(1)
     else:
-        update_processing(command.split())
-
-
-def update_processing(args):
-    """启动子进程更新rqsdk"""
-    try:
-        from pip import main
-    except ImportError:
-        from pip._internal import main
-    main(list(args))
-    if sys.platform.startswith("win"):
-        click.echo("请输入Enter继续...")
-    return
+        subprocess.check_call(["{} -m pip {} ".format(python_path, command)], shell=True)
 
 
 def update_bash_file(rqdatac_uri):
@@ -66,7 +54,3 @@ def update_bash_file(rqdatac_uri):
 
         with open(_path, "w", encoding="utf8")as f:
             f.writelines(lines)
-
-
-if __name__ == '__main__':
-    update_processing(sys.argv[1:])
